searchData={"items":[{"type":"module","title":"DprintMarkdownFormatter","doc":"A fast markdown formatter using dprint-plugin-markdown via Rustler NIF.\n\nThis module provides an interface to format markdown text using the\ndprint-plugin-markdown formatter implemented in Rust for performance.","ref":"DprintMarkdownFormatter.html"},{"type":"module","title":"Configuration - DprintMarkdownFormatter","doc":"Options for dprint can be configured in `mix.exs`:\n\n    def project do\n      [\n        # ... other config\n        dprint_markdown_formatter: [\n          line_width: 100,\n          text_wrap: :never,\n          emphasis_kind: :underscores,\n\n          # Enable formatting for default attributes (moduledoc, doc, typedoc, shortdoc, deprecated)\n          format_module_attributes: true,\n\n          # Or disable all formatting (default behavior)\n          # format_module_attributes: nil,\n\n          # Or specify custom attributes\n          # format_module_attributes: [:moduledoc, :doc, :custom_doc, :note]\n        ]\n      ]\n    end","ref":"DprintMarkdownFormatter.html#module-configuration"},{"type":"module","title":"Available Options - DprintMarkdownFormatter","doc":"- `:line_width` - Maximum line width (default: 80)\n- `:text_wrap` - Text wrapping behavior: `:always`, `:never`, `:maintain`\n  (default: `:always`)\n- `:emphasis_kind` - Emphasis style: `:asterisks`, `:underscores` (default:\n  `:asterisks`)\n- `:strong_kind` - Strong text style: `:asterisks`, `:underscores` (default:\n  `:asterisks`)\n- `:new_line_kind` - Line ending type: `:auto`, `:lf`, `:crlf` (default:\n  `:auto`)\n- `:unordered_list_kind` - Unordered list style: `:dashes`, `:asterisks`\n  (default: `:dashes`)\n\n**Note:** Configuration values can be provided as atoms (`:never`) or strings (`\"never\"`). \nAtoms are preferred for consistency with Elixir conventions.\n- `:format_module_attributes` - Configure which module attributes to format.\n  Supports four input types for maximum flexibility:\n\n  **`nil` (default):** Skip formatting all module attributes.\n\n  **Boolean `true`:** Format common documentation attributes: `:moduledoc`,\n  `:doc`, `:typedoc`, `:shortdoc`, `:deprecated`\n\n  **Boolean `false`:** Skip formatting all module attributes.\n\n  **List of atoms:** Format only the specified attributes. Any module attribute\n  containing string content can be specified. Examples:\n\n      # Format only module docs\n      format_module_attributes: [:moduledoc]\n\n      # Format standard docs plus custom attributes  \n      format_module_attributes: [:moduledoc, :doc, :custom_doc, :note, :example]\n\n      # Format testing attributes\n      format_module_attributes: [:moduletag, :tag, :describetag]\n\n  Only string values are processed (boolean `false` values are preserved\n  unchanged). Use `default_doc_attributes/0` to get the standard list.","ref":"DprintMarkdownFormatter.html#module-available-options"},{"type":"module","title":"Sigil Support - DprintMarkdownFormatter","doc":"For convenient markdown handling, you can use the ~M sigil:\n\n    import DprintMarkdownFormatter.Sigil\n\n    # Raw markdown\n    markdown = ~M\"\"\"\n    # Hello World\n\n    Some content here.\n    \"\"\"","ref":"DprintMarkdownFormatter.html#module-sigil-support"},{"type":"function","title":"DprintMarkdownFormatter.default_doc_attributes/0","doc":"Returns the default list of module attributes that are formatted when\n`format_module_attributes: true`.\n\nThis list includes the most commonly used documentation attributes in Elixir\nprojects.","ref":"DprintMarkdownFormatter.html#default_doc_attributes/0"},{"type":"function","title":"Examples - DprintMarkdownFormatter.default_doc_attributes/0","doc":"iex> DprintMarkdownFormatter.default_doc_attributes()\n    [:moduledoc, :doc, :typedoc, :shortdoc, :deprecated]\n\n    # Extend with custom attributes\n    custom_attrs = DprintMarkdownFormatter.default_doc_attributes() ++ [:custom_doc, :note]","ref":"DprintMarkdownFormatter.html#default_doc_attributes/0-examples"},{"type":"function","title":"DprintMarkdownFormatter.features/1","doc":"Returns the features supported by this formatter plugin.\n\nThis plugin supports:\n\n- The ~M sigil for markdown content\n- Files with .md and .markdown extensions (pure markdown)\n- Files with .ex and .exs extensions (module attributes only)","ref":"DprintMarkdownFormatter.html#features/1"},{"type":"function","title":"DprintMarkdownFormatter.format/2","doc":"Mix.Tasks.Format implementation for backward compatibility.\n\nThis is the actual function used by Mix formatter. It calls `format_with_errors/2` internally\nand returns the original content if formatting fails.","ref":"DprintMarkdownFormatter.html#format/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.format/2","doc":"iex> DprintMarkdownFormatter.format(\"# Hello    World\", [])\n    \"# Hello World\\n\"\n\n    iex> DprintMarkdownFormatter.format(\"# Hello    World\", extension: \".md\")\n    \"# Hello World\\n\"\n\n    iex> DprintMarkdownFormatter.format(\"# Hello    World\", sigil: :M)\n    \"# Hello World\"\n\n    iex> DprintMarkdownFormatter.format(\"# Hello    World\", line_width: 60)\n    \"# Hello World\\n\"\n\n    iex> DprintMarkdownFormatter.format(\"* Item 1\\n* Item 2\", unordered_list_kind: :asterisks)\n    \"* Item 1\\n* Item 2\\n\"","ref":"DprintMarkdownFormatter.html#format/2-examples"},{"type":"function","title":"DprintMarkdownFormatter.format_with_errors/2","doc":"Formats markdown text with error details.\n\nReturns `{:ok, formatted_content}` on success, or `{:error, error}` on failure.\nThis provides more detailed error information than the `Mix.Tasks.Format` version.","ref":"DprintMarkdownFormatter.html#format_with_errors/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.format_with_errors/2","doc":"iex> DprintMarkdownFormatter.format_with_errors(\"# Hello    World\", [])\n    {:ok, \"# Hello World\\n\"}\n\n    iex> DprintMarkdownFormatter.format_with_errors(\"# Hello\", line_width: 100)\n    {:ok, \"# Hello\\n\"}\n\n    # Error cases return detailed error information (e.g., invalid content types)\n    # {:error, %DprintMarkdownFormatter.Error.ValidationError{}} would be returned for invalid inputs","ref":"DprintMarkdownFormatter.html#format_with_errors/2-examples"},{"type":"module","title":"DprintMarkdownFormatter.Config","doc":"Configuration management for DprintMarkdownFormatter with proper type safety and\nvalidation.","ref":"DprintMarkdownFormatter.Config.html"},{"type":"function","title":"DprintMarkdownFormatter.Config.default/0","doc":"Returns the default configuration.","ref":"DprintMarkdownFormatter.Config.html#default/0"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.default/0","doc":"iex> DprintMarkdownFormatter.Config.default()\n    %DprintMarkdownFormatter.Config{\n      line_width: 80,\n      text_wrap: :always,\n      emphasis_kind: :asterisks,\n      strong_kind: :asterisks,\n      new_line_kind: :auto,\n      unordered_list_kind: :dashes,\n      format_module_attributes: nil\n    }","ref":"DprintMarkdownFormatter.Config.html#default/0-examples"},{"type":"function","title":"DprintMarkdownFormatter.Config.default_doc_attributes/0","doc":"Returns the default list of module attributes that are formatted when\n`format_module_attributes: true`.","ref":"DprintMarkdownFormatter.Config.html#default_doc_attributes/0"},{"type":"function","title":"DprintMarkdownFormatter.Config.from_keyword/1","doc":"Creates a configuration struct from a keyword list with validation.","ref":"DprintMarkdownFormatter.Config.html#from_keyword/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.from_keyword/1","doc":"iex> DprintMarkdownFormatter.Config.from_keyword([line_width: 100])\n    %DprintMarkdownFormatter.Config{line_width: 100}\n\n    iex> DprintMarkdownFormatter.Config.from_keyword([text_wrap: :never])\n    %DprintMarkdownFormatter.Config{text_wrap: :never}\n\n    iex> DprintMarkdownFormatter.Config.from_keyword([format_module_attributes: true])\n    %DprintMarkdownFormatter.Config{format_module_attributes: true}","ref":"DprintMarkdownFormatter.Config.html#from_keyword/1-examples"},{"type":"function","title":"DprintMarkdownFormatter.Config.load/0","doc":"Loads and validates configuration from Mix.Project.config().\n\nReturns a validated configuration struct with proper type checking. Invalid\nvalues are replaced with defaults and warnings are logged.","ref":"DprintMarkdownFormatter.Config.html#load/0"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.load/0","doc":"# With valid configuration in mix.exs\n    iex> DprintMarkdownFormatter.Config.load()\n    %DprintMarkdownFormatter.Config{line_width: 80, text_wrap: :always}\n\n    # With invalid configuration values (logs warnings and uses defaults)\n    iex> DprintMarkdownFormatter.Config.load()\n    %DprintMarkdownFormatter.Config{line_width: 80, text_wrap: :always}","ref":"DprintMarkdownFormatter.Config.html#load/0-examples"},{"type":"function","title":"DprintMarkdownFormatter.Config.merge/2","doc":"Merges a configuration struct with runtime options.\n\nRuntime options take precedence over configuration values. Only valid\noptions are merged; invalid options are ignored with a warning.","ref":"DprintMarkdownFormatter.Config.html#merge/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.merge/2","doc":"iex> config = %DprintMarkdownFormatter.Config{line_width: 80}\n    iex> DprintMarkdownFormatter.Config.merge(config, [line_width: 100])\n    %DprintMarkdownFormatter.Config{line_width: 100}\n\n    iex> config = %DprintMarkdownFormatter.Config{text_wrap: :always}\n    iex> DprintMarkdownFormatter.Config.merge(config, [text_wrap: :never, line_width: 120])\n    %DprintMarkdownFormatter.Config{text_wrap: :never, line_width: 120}","ref":"DprintMarkdownFormatter.Config.html#merge/2-examples"},{"type":"function","title":"DprintMarkdownFormatter.Config.resolve_module_attributes/1","doc":"Resolves module attributes configuration to a list of atoms.","ref":"DprintMarkdownFormatter.Config.html#resolve_module_attributes/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.resolve_module_attributes/1","doc":"iex> config = %DprintMarkdownFormatter.Config{format_module_attributes: true}\n    iex> DprintMarkdownFormatter.Config.resolve_module_attributes(config)\n    [:moduledoc, :doc, :typedoc, :shortdoc, :deprecated]\n\n    iex> config = %DprintMarkdownFormatter.Config{format_module_attributes: [:custom]}\n    iex> DprintMarkdownFormatter.Config.resolve_module_attributes(config)\n    [:custom]\n\n    iex> config = %DprintMarkdownFormatter.Config{format_module_attributes: nil}\n    iex> DprintMarkdownFormatter.Config.resolve_module_attributes(config)\n    []","ref":"DprintMarkdownFormatter.Config.html#resolve_module_attributes/1-examples"},{"type":"type","title":"DprintMarkdownFormatter.Config.t/0","doc":"","ref":"DprintMarkdownFormatter.Config.html#t:t/0"},{"type":"function","title":"DprintMarkdownFormatter.Config.to_nif_config/1","doc":"Returns a map with only the dprint-related fields for the NIF.\n\nExcludes format_module_attributes which is only used by Elixir code.\nThis map is passed directly to the Rust NIF for formatting.","ref":"DprintMarkdownFormatter.Config.html#to_nif_config/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Config.to_nif_config/1","doc":"iex> config = %DprintMarkdownFormatter.Config{line_width: 100, text_wrap: :never}\n    iex> DprintMarkdownFormatter.Config.to_nif_config(config)\n    %{line_width: 100, text_wrap: :never, emphasis_kind: :asterisks}","ref":"DprintMarkdownFormatter.Config.html#to_nif_config/1-examples"},{"type":"module","title":"DprintMarkdownFormatter.Error","doc":"Error utilities for DprintMarkdownFormatter.\n\nThis module provides validation errors and helper functions for creating\nstandard Elixir exceptions with descriptive messages.","ref":"DprintMarkdownFormatter.Error.html"},{"type":"function","title":"DprintMarkdownFormatter.Error.config_error/2","doc":"Creates an argument error for configuration issues.","ref":"DprintMarkdownFormatter.Error.html#config_error/2"},{"type":"function","title":"DprintMarkdownFormatter.Error.format_error/2","doc":"Creates a runtime error for formatting failures.","ref":"DprintMarkdownFormatter.Error.html#format_error/2"},{"type":"function","title":"DprintMarkdownFormatter.Error.nif_error/2","doc":"Creates a runtime error for NIF failures.\n\nUsed when the Rust NIF returns an error during markdown formatting.","ref":"DprintMarkdownFormatter.Error.html#nif_error/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Error.nif_error/2","doc":"iex> DprintMarkdownFormatter.Error.nif_error(\"NIF formatting failed\")\n    %RuntimeError{message: \"NIF formatting failed\"}\n\n    iex> DprintMarkdownFormatter.Error.nif_error(\"NIF error\", original_error: \"Invalid markdown syntax\")\n    %RuntimeError{message: \"NIF error: Invalid markdown syntax\"}","ref":"DprintMarkdownFormatter.Error.html#nif_error/2-examples"},{"type":"function","title":"DprintMarkdownFormatter.Error.parse_error/2","doc":"Creates a runtime error for parsing failures.\n\nUsed when Elixir code parsing fails, such as when processing module attributes.","ref":"DprintMarkdownFormatter.Error.html#parse_error/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Error.parse_error/2","doc":"iex> DprintMarkdownFormatter.Error.parse_error(\"Failed to parse code\")\n    %RuntimeError{message: \"Failed to parse code\"}\n\n    iex> original_error = %SyntaxError{message: \"unexpected token\"}\n    iex> DprintMarkdownFormatter.Error.parse_error(\"Parse failed\", original_error: original_error)\n    %RuntimeError{message: \"Parse failed: %SyntaxError{message: \\\"unexpected token\\\"}\"}","ref":"DprintMarkdownFormatter.Error.html#parse_error/2-examples"},{"type":"type","title":"DprintMarkdownFormatter.Error.t/0","doc":"","ref":"DprintMarkdownFormatter.Error.html#t:t/0"},{"type":"function","title":"DprintMarkdownFormatter.Error.validation_error/2","doc":"Creates a validation error.","ref":"DprintMarkdownFormatter.Error.html#validation_error/2"},{"type":"module","title":"DprintMarkdownFormatter.Sigil","doc":"Provides the ~M sigil for embedding markdown content in Elixir code.\n\nThe ~M sigil creates markdown strings that can be used directly in your\napplication without any additional processing.","ref":"DprintMarkdownFormatter.Sigil.html"},{"type":"module","title":"Usage - DprintMarkdownFormatter.Sigil","doc":"import DprintMarkdownFormatter.Sigil\n\n    # Simple markdown\n    title = ~M\"# Welcome to My App\"\n\n    # Multi-line markdown with code blocks\n    docs = ~M\"\"\"\n    # API Documentation","ref":"DprintMarkdownFormatter.Sigil.html#module-usage"},{"type":"module","title":"Authentication - DprintMarkdownFormatter.Sigil","doc":"```elixir\n    defmodule MyApp.Auth do\n      def authenticate(token) do\n        # Implementation here\n      end\n    end\n    ```","ref":"DprintMarkdownFormatter.Sigil.html#module-authentication"},{"type":"module","title":"Usage - DprintMarkdownFormatter.Sigil","doc":"Call the authenticate function with your token.\n    \"\"\"","ref":"DprintMarkdownFormatter.Sigil.html#module-usage-1"},{"type":"module","title":"Modifiers - DprintMarkdownFormatter.Sigil","doc":"The ~M sigil ignores all modifiers and always returns the raw markdown string.","ref":"DprintMarkdownFormatter.Sigil.html#module-modifiers"},{"type":"function","title":"DprintMarkdownFormatter.Sigil.sigil_M/2","doc":"Creates a markdown string from the given content.\n\nThe ~M sigil creates a raw markdown string that can be formatted by `mix format`\nwhen the DprintMarkdownFormatter plugin is configured.","ref":"DprintMarkdownFormatter.Sigil.html#sigil_M/2"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Sigil.sigil_M/2","doc":"iex> import DprintMarkdownFormatter.Sigil\n    iex> ~M\"# Hello World\"\n    \"# Hello World\"\n\n    iex> import DprintMarkdownFormatter.Sigil\n    iex> ~M\"**Bold** and *italic* text\"\n    \"**Bold** and *italic* text\"\n\n    iex> import DprintMarkdownFormatter.Sigil\n    iex> ~M\"\"\"\n    ...> # Title\n    ...> \n    ...> Content here.\n    ...> \"\"\"\n    \"# Title\\n\\nContent here.\\n\"","ref":"DprintMarkdownFormatter.Sigil.html#sigil_M/2-examples"},{"type":"module","title":"DprintMarkdownFormatter.Native","doc":"Native interface for dprint markdown formatting using Rustler.\n\nThis module loads the Rust NIF that provides the actual formatting\nfunctionality.","ref":"DprintMarkdownFormatter.Native.html"},{"type":"function","title":"DprintMarkdownFormatter.Native.format_markdown/2","doc":"Formats markdown text with configurable options.\n\nThis function is implemented in Rust and provides the core formatting\nfunctionality using the dprint-plugin-markdown library.","ref":"DprintMarkdownFormatter.Native.html#format_markdown/2"},{"type":"function","title":"Parameters - DprintMarkdownFormatter.Native.format_markdown/2","doc":"- `text` - The markdown text to format\n- `options` - A map of formatting options (see `format_options/0` type)","ref":"DprintMarkdownFormatter.Native.html#format_markdown/2-parameters"},{"type":"function","title":"Returns - DprintMarkdownFormatter.Native.format_markdown/2","doc":"- `{:ok, formatted_text}` on successful formatting\n- `{:error, error_message}` if formatting fails","ref":"DprintMarkdownFormatter.Native.html#format_markdown/2-returns"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Native.format_markdown/2","doc":"iex> options = %{line_width: 80, text_wrap: :always, emphasis_kind: :asterisks, strong_kind: :asterisks, new_line_kind: :auto, unordered_list_kind: :dashes}\n    iex> DprintMarkdownFormatter.Native.format_markdown(\"# Hello    World\", options)\n    {:ok, \"# Hello World\\n\"}\n\n    iex> DprintMarkdownFormatter.Native.format_markdown(\"*   Item 1\\n*   Item 2\", options)\n    {:ok, \"- Item 1\\n- Item 2\\n\"}","ref":"DprintMarkdownFormatter.Native.html#format_markdown/2-examples"},{"type":"module","title":"DprintMarkdownFormatter.Validator","doc":"Input validation utilities for DprintMarkdownFormatter.\n\nProvides comprehensive validation for all inputs including content, \noptions, and configuration values.","ref":"DprintMarkdownFormatter.Validator.html"},{"type":"function","title":"DprintMarkdownFormatter.Validator.validate_config/1","doc":"Validates a configuration struct.","ref":"DprintMarkdownFormatter.Validator.html#validate_config/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Validator.validate_config/1","doc":"iex> config = %DprintMarkdownFormatter.Config{}\n    iex> DprintMarkdownFormatter.Validator.validate_config(config)\n    {:ok, config}","ref":"DprintMarkdownFormatter.Validator.html#validate_config/1-examples"},{"type":"function","title":"DprintMarkdownFormatter.Validator.validate_content/1","doc":"Validates content input for formatting.","ref":"DprintMarkdownFormatter.Validator.html#validate_content/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Validator.validate_content/1","doc":"iex> DprintMarkdownFormatter.Validator.validate_content(\"# Hello\")\n    {:ok, \"# Hello\"}\n\n    iex> DprintMarkdownFormatter.Validator.validate_content(\"\")\n    {:ok, \"\"}\n\n    iex> DprintMarkdownFormatter.Validator.validate_content(nil)\n    {:error, %DprintMarkdownFormatter.Error.ValidationError{}}","ref":"DprintMarkdownFormatter.Validator.html#validate_content/1-examples"},{"type":"function","title":"DprintMarkdownFormatter.Validator.validate_options/1","doc":"Validates formatting options.\n\nEnsures that options are provided as a keyword list and all values are valid.\nUnknown options are allowed for forward compatibility.","ref":"DprintMarkdownFormatter.Validator.html#validate_options/1"},{"type":"function","title":"Examples - DprintMarkdownFormatter.Validator.validate_options/1","doc":"iex> DprintMarkdownFormatter.Validator.validate_options([line_width: 80])\n    {:ok, [line_width: 80]}\n\n    iex> DprintMarkdownFormatter.Validator.validate_options([line_width: 80, text_wrap: :never])\n    {:ok, [line_width: 80, text_wrap: :never]}\n\n    iex> DprintMarkdownFormatter.Validator.validate_options(%{line_width: 80})\n    {:error, %DprintMarkdownFormatter.Error.ValidationError{}}\n\n    iex> DprintMarkdownFormatter.Validator.validate_options([line_width: -1])\n    {:error, %DprintMarkdownFormatter.Error.ValidationError{}}","ref":"DprintMarkdownFormatter.Validator.html#validate_options/1-examples"},{"type":"exception","title":"DprintMarkdownFormatter.Error.ValidationError","doc":"Error when input validation fails.","ref":"DprintMarkdownFormatter.Error.ValidationError.html"},{"type":"type","title":"DprintMarkdownFormatter.Error.ValidationError.t/0","doc":"","ref":"DprintMarkdownFormatter.Error.ValidationError.html#t:t/0"},{"type":"extras","title":"DprintMarkdownFormatter","doc":"# DprintMarkdownFormatter\n\n[![Hex.pm](https://img.shields.io/hexpm/v/dprint_markdown_formatter.svg)](https://hex.pm/packages/dprint_markdown_formatter)\n[![Documentation](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/dprint_markdown_formatter/)\n\nA fast, configurable markdown formatter for Elixir that combines the power of\nRust's `dprint-plugin-markdown` with native Elixir integration.","ref":"readme.html"},{"type":"extras","title":"Features - DprintMarkdownFormatter","doc":"- **🚀 High Performance**: Uses Rust's `dprint-plugin-markdown` via Rustler NIFs\n- **🔧 Highly Configurable**: Extensive formatting options for line width, text\n  wrapping, emphasis styles, and more\n- **📝 Module Attribute Formatting**: Automatically formats markdown in\n  `@moduledoc`, `@doc`, etc.\n- **🎯 Mix Integration**: Works seamlessly with `mix format`\n- **🔤 Sigil Support**: Provides `~M` sigil for embedding markdown\n- **📦 Precompiled Binaries**: Fast installation without requiring Rust\n  toolchain","ref":"readme.html#features"},{"type":"extras","title":"Installation - DprintMarkdownFormatter","doc":"Add to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:dprint_markdown_formatter, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - DprintMarkdownFormatter","doc":"","ref":"readme.html#quick-start"},{"type":"extras","title":"Basic Usage - DprintMarkdownFormatter","doc":"```elixir\n# Format a single string\nmarkdown = \"\"\"\n#    Poorly   Formatted   Title\n\nThis is a paragraph with    extra   spaces.\n\n*   Inconsistent list\n*   Another    item\n\"\"\"\n\nformatted = DprintMarkdownFormatter.format(markdown, [])\n\n# Output:\n# # Poorly Formatted Title\n# \n# This is a paragraph with extra spaces.\n# \n# - Inconsistent list\n# - Another item\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Sigil Usage - DprintMarkdownFormatter","doc":"Use the `~M` sigil for embedding markdown content that gets automatically\nformatted by `mix format`:\n\n```elixir\nimport DprintMarkdownFormatter.Sigil\n\n# This markdown will be automatically formatted when you run `mix format`\nmarkdown = ~M\"\"\"\n# API   Documentation   \n\nThis is **bold** text with    extra   spaces.\n\n*   Poorly   formatted   list\n\"\"\"\n\n# After `mix format`, the sigil content becomes properly formatted\n```","ref":"readme.html#sigil-usage"},{"type":"extras","title":"Integration with mix format - DprintMarkdownFormatter","doc":"Add to your `.formatter.exs`:\n\n```elixir\n[\n  plugins: [DprintMarkdownFormatter]\n]\n```\n\nThis enables automatic formatting of `.md` and `.markdown` files. To also format\nmodule attributes, configure `format_module_attributes` in your project.","ref":"readme.html#integration-with-mix-format"},{"type":"extras","title":"Configuration - DprintMarkdownFormatter","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Global Configuration - DprintMarkdownFormatter","doc":"Configure in your `mix.exs`:\n\n```elixir\ndef project do\n  [\n    # ... other config\n    dprint_markdown_formatter: [\n      line_width: 100,\n      text_wrap: :never,\n      emphasis_kind: :underscores,\n      format_module_attributes: true  # Enable module attribute formatting\n    ]\n  ]\nend\n```","ref":"readme.html#global-configuration"},{"type":"extras","title":"Per-call Configuration - DprintMarkdownFormatter","doc":"```elixir\nopts = [\n  line_width: 120,\n  text_wrap: :never,\n  emphasis_kind: :underscores,\n  unordered_list_kind: :asterisks\n]\n\nDprintMarkdownFormatter.format(markdown, opts)\n```","ref":"readme.html#per-call-configuration"},{"type":"extras","title":"Available Options - DprintMarkdownFormatter","doc":"| Option                      | Default      | Description                                     |\n| --------------------------- | ------------ | ----------------------------------------------- |\n| `:line_width`               | `80`         | Maximum line width                              |\n| `:text_wrap`                | `:always`    | Text wrapping: `:always`, `:never`, `:maintain` |\n| `:emphasis_kind`            | `:asterisks` | Emphasis style: `:asterisks`, `:underscores`    |\n| `:strong_kind`              | `:asterisks` | Strong text style: `:asterisks`, `:underscores` |\n| `:unordered_list_kind`      | `:dashes`    | List style: `:dashes`, `:asterisks`             |\n| `:format_module_attributes` | `nil`        | Module attribute formatting (see below)         |\n\n**Note:** Configuration values can be provided as atoms (`:never`) or strings\n(`\"never\"`). Atoms are preferred for consistency with Elixir conventions.","ref":"readme.html#available-options"},{"type":"extras","title":"Module Attribute Configuration - DprintMarkdownFormatter","doc":"```elixir\n# Skip all formatting (default)\nformat_module_attributes: nil\n\n# Format common doc attributes\nformat_module_attributes: true  # [:moduledoc, :doc, :typedoc, :shortdoc, :deprecated]\n\n# Format specific attributes only\nformat_module_attributes: [:moduledoc, :doc, :custom_doc]\n```","ref":"readme.html#module-attribute-configuration"},{"type":"extras","title":"Module Attribute Formatting Example - DprintMarkdownFormatter","doc":"Before `mix format`:\n\n```elixir\ndefmodule MyModule do\n  @moduledoc \"\"\"\n  This is   messy   markdown   content.\n  \n  *   Poorly formatted list\n  *   Another    item\n  \"\"\"\n  \n  @doc \"\"\"\n  Function documentation with    extra   spaces.\n  \"\"\"\n  def my_function, do: :ok\nend\n```\n\nAfter `mix format`:\n\n```elixir\ndefmodule MyModule do\n  @moduledoc \"\"\"\n  This is messy markdown content.\n  \n  - Properly formatted list\n  - Another item\n  \"\"\"\n  \n  @doc \"\"\"\n  Function documentation with extra spaces.\n  \"\"\"\n  def my_function, do: :ok\nend\n```","ref":"readme.html#module-attribute-formatting-example"},{"type":"extras","title":"Troubleshooting - DprintMarkdownFormatter","doc":"","ref":"readme.html#troubleshooting"},{"type":"extras","title":"Module attributes not being formatted - DprintMarkdownFormatter","doc":"Make sure you have:\n\n1. Added `plugins: [DprintMarkdownFormatter]` to `.formatter.exs`\n2. Configured `format_module_attributes: true` in your `mix.exs`\n3. Run `mix format` on your `.ex` files","ref":"readme.html#module-attributes-not-being-formatted"},{"type":"extras","title":"Compilation issues - DprintMarkdownFormatter","doc":"If you see Rust compilation errors, you can force using precompiled binaries:\n\n```bash\nexport RUSTLER_PRECOMPILED_FORCE_BUILD=false\nmix deps.get\n```","ref":"readme.html#compilation-issues"},{"type":"extras","title":"Development - DprintMarkdownFormatter","doc":"","ref":"readme.html#development"},{"type":"extras","title":"Prerequisites - DprintMarkdownFormatter","doc":"- Elixir 1.16+\n- Rust toolchain (optional, precompiled binaries available)","ref":"readme.html#prerequisites"},{"type":"extras","title":"Commands - DprintMarkdownFormatter","doc":"```bash\n# Setup\nmix deps.get\nmix compile\n\n# Development\nmix test              # Run tests\nmix check            # Run all quality checks (format, credo, dialyzer, cargo fmt, cargo clippy)\nmix format           # Format Elixir code\nmix credo            # Static analysis\nmix dialyzer         # Type checking\n\n# Rust development (in native/dprint_markdown_formatter/)\ncargo build          # Build the NIF\ncargo test           # Run Rust tests\n```","ref":"readme.html#commands"},{"type":"extras","title":"Architecture - DprintMarkdownFormatter","doc":"- **Elixir Layer**: Public API, configuration management, Mix integration\n- **Rust NIF**: Core formatting engine using `dprint-plugin-markdown`\n- **Rustler**: Type-safe bridge between Elixir and Rust","ref":"readme.html#architecture"},{"type":"extras","title":"Key Components - DprintMarkdownFormatter","doc":"- `DprintMarkdownFormatter`: Main public API\n- `DprintMarkdownFormatter.Native`: Rustler NIF wrapper\n- `DprintMarkdownFormatter.Sigil`: `~M` sigil implementation","ref":"readme.html#key-components"},{"type":"extras","title":"License - DprintMarkdownFormatter","doc":"MIT License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Code Generation - DprintMarkdownFormatter","doc":"This project was generated and developed with assistance from\n[Claude Code](https://claude.ai/code), Anthropic's AI coding assistant. All\ncommits in this repository include co-author attribution to Claude.","ref":"readme.html#code-generation"},{"type":"extras","title":"Acknowledgments - DprintMarkdownFormatter","doc":"- Built on\n  [dprint-plugin-markdown](https://github.com/dprint/dprint-plugin-markdown)\n- Uses [Rustler](https://github.com/rusterlium/rustler) for Elixir/Rust\n  integration","ref":"readme.html#acknowledgments"},{"type":"extras","title":"llms","doc":"# DprintMarkdownFormatter Usage Guide for LLMs\n\nThis guide helps LLMs understand how to use the DprintMarkdownFormatter package effectively.","ref":"llms.html"},{"type":"extras","title":"Package Overview - llms","doc":"DprintMarkdownFormatter is a fast, configurable markdown formatter for Elixir that uses Rust's `dprint-plugin-markdown` via NIFs. It provides:\n\n- High-performance markdown formatting\n- Mix format integration for .md files\n- Module attribute formatting (@moduledoc, @doc, etc.)\n- Sigil support (~M)\n- Extensive configuration options","ref":"llms.html#package-overview"},{"type":"extras","title":"Quick Start - llms","doc":"","ref":"llms.html#quick-start"},{"type":"extras","title":"Installation - llms","doc":"Add to `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:dprint_markdown_formatter, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"llms.html#installation"},{"type":"extras","title":"Basic Usage - llms","doc":"```elixir\n# Format a markdown string\nmarkdown = \"# Poorly   Formatted   Title\\n\\nThis has    extra   spaces.\"\nformatted = DprintMarkdownFormatter.format(markdown, [])\n# => \"# Poorly Formatted Title\\n\\nThis has extra spaces.\\n\"\n```","ref":"llms.html#basic-usage"},{"type":"extras","title":"Configuration - llms","doc":"","ref":"llms.html#configuration"},{"type":"extras","title":"Global Configuration (mix.exs) - llms","doc":"```elixir\ndef project do\n  [\n    # ... other config\n    dprint_markdown_formatter: [\n      line_width: 100,\n      text_wrap: :never,\n      emphasis_kind: :underscores,\n      format_module_attributes: true\n    ]\n  ]\nend\n```","ref":"llms.html#global-configuration-mix-exs"},{"type":"extras","title":"Per-Call Configuration - llms","doc":"```elixir\nopts = [\n  line_width: 120,\n  text_wrap: :never,\n  emphasis_kind: :underscores\n]\n\nDprintMarkdownFormatter.format(markdown, opts)\n```","ref":"llms.html#per-call-configuration"},{"type":"extras","title":"Configuration Options - llms","doc":"| Option | Default | Values | Description |\n|--------|---------|--------|-------------|\n| `:line_width` | `80` | positive integer | Maximum line width |\n| `:text_wrap` | `:always` | `:always`, `:never`, `:maintain` | Text wrapping behavior |\n| `:emphasis_kind` | `:asterisks` | `:asterisks`, `:underscores` | Emphasis style (*text* vs _text_) |\n| `:strong_kind` | `:asterisks` | `:asterisks`, `:underscores` | Strong text style (**text** vs __text__) |\n| `:unordered_list_kind` | `:dashes` | `:dashes`, `:asterisks` | List style (- vs *) |\n| `:new_line_kind` | `:auto` | `:auto`, `:lf`, `:crlf` | Line ending type |\n| `:format_module_attributes` | `nil` | `nil`, `true`, `false`, `[atom()]` | Module attribute formatting |\n\n**Note**: Configuration values can be atoms (`:never`) or strings (`\"never\"`). Atoms are preferred.","ref":"llms.html#configuration-options"},{"type":"extras","title":"Usage Patterns - llms","doc":"","ref":"llms.html#usage-patterns"},{"type":"extras","title":"1. Direct API Usage - llms","doc":"```elixir\n# Simple formatting\nresult = DprintMarkdownFormatter.format(markdown_text, [])\n\n# With custom options\nresult = DprintMarkdownFormatter.format(markdown_text, [\n  line_width: 120,\n  text_wrap: :never\n])\n```","ref":"llms.html#1-direct-api-usage"},{"type":"extras","title":"2. Mix Format Integration - llms","doc":"Add to `.formatter.exs`:\n\n```elixir\n[\n  plugins: [DprintMarkdownFormatter]\n]\n```\n\nThis enables automatic formatting of `.md` and `.markdown` files when running `mix format`.","ref":"llms.html#2-mix-format-integration"},{"type":"extras","title":"3. Sigil Usage - llms","doc":"```elixir\nimport DprintMarkdownFormatter.Sigil\n\n# Sigil content gets formatted by mix format\nmarkdown = ~M\"\"\"\n# API   Documentation   \n\nThis is **bold** text with    extra   spaces.\n\n*   Poorly   formatted   list\n\"\"\"\n```","ref":"llms.html#3-sigil-usage"},{"type":"extras","title":"4. Module Attribute Formatting - llms","doc":"Enable in `mix.exs`:\n\n```elixir\ndprint_markdown_formatter: [\n  format_module_attributes: true  # Format default attributes\n]\n```\n\nThis formats markdown in `@moduledoc`, `@doc`, `@typedoc`, `@shortdoc`, and `@deprecated`.\n\nCustom attributes:\n\n```elixir\ndprint_markdown_formatter: [\n  format_module_attributes: [:moduledoc, :doc, :custom_doc]\n]\n```","ref":"llms.html#4-module-attribute-formatting"},{"type":"extras","title":"Module Attribute Formatting - llms","doc":"","ref":"llms.html#module-attribute-formatting"},{"type":"extras","title":"Setup Requirements - llms","doc":"1. Add plugin to `.formatter.exs`:\n   ```elixir\n   [\n     plugins: [DprintMarkdownFormatter]\n   ]\n   ```\n\n2. Configure in `mix.exs`:\n   ```elixir\n   dprint_markdown_formatter: [\n     format_module_attributes: true\n   ]\n   ```\n\n3. Run `mix format` on your `.ex` files","ref":"llms.html#setup-requirements"},{"type":"extras","title":"How It Works - llms","doc":"Before formatting:\n```elixir\ndefmodule MyModule do\n  @moduledoc \"\"\"\n  This is   messy   markdown.\n  \n  *   Poorly formatted list\n  *   Another    item\n  \"\"\"\n  \n  @doc \"\"\"\n  Function docs with    extra   spaces.\n  \"\"\"\n  def my_function, do: :ok\nend\n```\n\nAfter `mix format`:\n```elixir\ndefmodule MyModule do\n  @moduledoc \"\"\"\n  This is messy markdown.\n  \n  - Properly formatted list\n  - Another item\n  \"\"\"\n  \n  @doc \"\"\"\n  Function docs with extra spaces.\n  \"\"\"\n  def my_function, do: :ok\nend\n```","ref":"llms.html#how-it-works"},{"type":"extras","title":"Common Use Cases - llms","doc":"","ref":"llms.html#common-use-cases"},{"type":"extras","title":"1. Documentation Formatting - llms","doc":"```elixir\n# Format README or documentation files\ncontent = File.read!(\"README.md\")\nformatted = DprintMarkdownFormatter.format(content, [line_width: 100])\nFile.write!(\"README.md\", formatted)\n```","ref":"llms.html#1-documentation-formatting"},{"type":"extras","title":"2. CI/CD Integration - llms","doc":"```bash\n# Check if markdown files are properly formatted\nmix format --check-formatted\n```","ref":"llms.html#2-ci-cd-integration"},{"type":"extras","title":"3. Custom Formatting Workflows - llms","doc":"```elixir\ndef format_all_docs do\n  Path.wildcard(\"docs/**/*.md\")\n  |> Enum.each(fn file ->\n    content = File.read!(file)\n    formatted = DprintMarkdownFormatter.format(content, [\n      line_width: 100,\n      text_wrap: :never\n    ])\n    File.write!(file, formatted)\n  end)\nend\n```","ref":"llms.html#3-custom-formatting-workflows"},{"type":"extras","title":"Troubleshooting - llms","doc":"","ref":"llms.html#troubleshooting"},{"type":"extras","title":"Module Attributes Not Being Formatted - llms","doc":"**Check these steps in order:**\n\n1. **Plugin configuration**: Ensure `.formatter.exs` has:\n   ```elixir\n   [\n     plugins: [DprintMarkdownFormatter]\n   ]\n   ```\n\n2. **Module attribute configuration**: Ensure `mix.exs` has:\n   ```elixir\n   dprint_markdown_formatter: [\n     format_module_attributes: true  # or custom list\n   ]\n   ```\n\n3. **Run on .ex files**: Module attributes are formatted when you run `mix format` on `.ex` files, not `.md` files.\n\n4. **Check attribute names**: Default formatting only applies to `:moduledoc`, `:doc`, `:typedoc`, `:shortdoc`, `:deprecated`.","ref":"llms.html#module-attributes-not-being-formatted"},{"type":"extras","title":"Compilation Issues - llms","doc":"If you see Rust compilation errors, force precompiled binaries:\n\n```bash\nexport RUSTLER_PRECOMPILED_FORCE_BUILD=false\nmix deps.get\nmix compile\n```","ref":"llms.html#compilation-issues"},{"type":"extras","title":"Configuration Not Taking Effect - llms","doc":"- **Global config**: Must be in `mix.exs` under `dprint_markdown_formatter` key\n- **Per-call config**: Passed as second argument to `format/2`\n- **Mix format**: Uses global config from `mix.exs`","ref":"llms.html#configuration-not-taking-effect"},{"type":"extras","title":"Performance Considerations - llms","doc":"- **Large files**: The formatter is optimized for performance but very large files (>1MB) may take time\n- **Batch processing**: For many files, consider parallel processing with `Task.async_stream/2`\n- **Caching**: The formatter is deterministic - same input always produces same output","ref":"llms.html#performance-considerations"},{"type":"extras","title":"Advanced Usage - llms","doc":"","ref":"llms.html#advanced-usage"},{"type":"extras","title":"Custom Attribute Formatting - llms","doc":"```elixir\n# Format specific attributes only\ndprint_markdown_formatter: [\n  format_module_attributes: [\n    :moduledoc,\n    :doc,\n    :api_doc,      # custom attribute\n    :example_doc   # custom attribute\n  ]\n]\n```","ref":"llms.html#custom-attribute-formatting"},{"type":"extras","title":"Complex Configuration - llms","doc":"```elixir\ndprint_markdown_formatter: [\n  line_width: 120,\n  text_wrap: :never,\n  emphasis_kind: :underscores,\n  strong_kind: :underscores,\n  unordered_list_kind: :asterisks,\n  format_module_attributes: [\n    :moduledoc,\n    :doc,\n    :typedoc,\n    :spec_doc,\n    :example_doc\n  ]\n]\n```","ref":"llms.html#complex-configuration"},{"type":"extras","title":"Integration with Other Tools - llms","doc":"```elixir\n# Use with ExDoc\ndef format_doc_files do\n  \"doc/**/*.md\"\n  |> Path.wildcard()\n  |> Enum.each(&format_file/1)\nend\n\ndefp format_file(file) do\n  content = File.read!(file)\n  formatted = DprintMarkdownFormatter.format(content, [\n    line_width: 100,\n    text_wrap: :maintain\n  ])\n  File.write!(file, formatted)\nend\n```","ref":"llms.html#integration-with-other-tools"},{"type":"extras","title":"Best Practices - llms","doc":"1. **Use atoms for config values**: `:never` instead of `\"never\"`\n2. **Set reasonable line widths**: 80-120 characters work well\n3. **Consider text wrapping**: `:maintain` preserves existing line breaks\n4. **Test configuration**: Start with defaults, then customize\n5. **Use in CI**: Add `mix format --check-formatted` to ensure consistent formatting\n6. **Document custom attributes**: If using custom module attributes, document them for your team","ref":"llms.html#best-practices"},{"type":"extras","title":"Performance Tips - llms","doc":"- The formatter is very fast due to Rust implementation\n- For large batches of files, use `Task.async_stream/2` for parallel processing\n- Configuration parsing is cached, so repeated calls with same options are efficient\n- Empty or very small strings are handled efficiently with early returns","ref":"llms.html#performance-tips"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}